@@ -1,5 +1,5 @@
 /* example5.c --- Example TLD checking.
- * Copyright (C) 2004-2016 Simon Josefsson
+ * Copyright (C) 2004-2020 Simon Josefsson
  *
  * This file is part of GNU Libidn.
  *
@@ -107,7 +107,8 @@ main (void)
   free (r);
   if (rc == TLD_INVALID)
     {
-      printf ("Domain rejected by TLD check, Unicode position %ld\n", (long int) errpos);
+      printf ("Domain rejected by TLD check, Unicode position %ld\n",
+	      (long int) errpos);
       return 1;
     }
   else if (rc != TLD_SUCCESS)
