@@ -1,5 +1,5 @@
 /* stringprep.c --- Core stringprep implementation.
-   Copyright (C) 2002-2016 Simon Josefsson
+   Copyright (C) 2002-2020 Simon Josefsson
 
    This file is part of GNU Libidn.
 
@@ -37,7 +37,8 @@
 #include "stringprep.h"
 
 static int
-_compare_table_element (const uint32_t * c, const Stringprep_table_element * e)
+_compare_table_element (const uint32_t * c,
+			const Stringprep_table_element * e)
 {
   if (*c < e->start)
     return -1;
@@ -49,7 +50,7 @@ _compare_table_element (const uint32_t * c, const Stringprep_table_element * e)
 static ssize_t
 stringprep_find_character_in_table (uint32_t ucs4,
 				    const Stringprep_table_element * table,
-                                    size_t table_size)
+				    size_t table_size)
 {
   /* This is where typical uses of Libidn spends very close to all CPU
      time and causes most cache misses.  One could easily do a binary
@@ -58,44 +59,46 @@ stringprep_find_character_in_table (uint32_t ucs4,
      dispute optimization may improve matters significantly, I'm
      mostly interested in having someone give real-world benchmark on
      the impact of libidn.)
-   *
-   * Answer (Tim Rühsen rockdaboot@gmx.de):
-   * Testing the fuzz corpora just once via make check takes ~54 billion CPU cycles.
-   * That is almost 20s on my Intel i3 3.1GHz !!!
-   * That even makes fuzzing almost useless, eating up CPU cycles for nothing.
-   *
-   * The bsearch() approach takes ~3 billion CPU cycles.
-   * Almost a factor of 20 faster (but still pretty slow).
-   * There are still ~2 million calls to bsearch() which make ~30% of CPU time used.
-   * Most time is spent in _g_utf8_normalize_wc().
+     *
+     * Answer (Tim Rühsen rockdaboot@gmx.de):
+     * Testing the fuzz corpora just once via make check takes ~54 billion CPU cycles.
+     * That is almost 20s on my Intel i3 3.1GHz !!!
+     * That even makes fuzzing almost useless, eating up CPU cycles for nothing.
+     *
+     * The bsearch() approach takes ~3 billion CPU cycles.
+     * Almost a factor of 20 faster (but still pretty slow).
+     * There are still ~2 million calls to bsearch() which make ~30% of CPU time used.
+     * Most time is spent in _g_utf8_normalize_wc().
 
-  ssize_t i;
+     ssize_t i;
 
-  for (i = 0; table[i].start || table[i].end; i++)
-    if (ucs4 >= table[i].start &&
-	ucs4 <= (table[i].end ? table[i].end : table[i].start))
-      return i;
-  */
+     for (i = 0; table[i].start || table[i].end; i++)
+     if (ucs4 >= table[i].start &&
+     ucs4 <= (table[i].end ? table[i].end : table[i].start))
+     return i;
+   */
 
-  const Stringprep_table_element * p =
-    bsearch (&ucs4, table, table_size, sizeof(Stringprep_table_element),
-             (int (*)(const void *, const void *)) _compare_table_element);
+  const Stringprep_table_element *p =
+    bsearch (&ucs4, table, table_size, sizeof (Stringprep_table_element),
+	     (int (*)(const void *, const void *)) _compare_table_element);
 
-   return p ? (p - table) : -1;
+  return p ? (p - table) : -1;
 }
 
 static ssize_t
 stringprep_find_string_in_table (uint32_t * ucs4,
 				 size_t ucs4len,
-				 size_t * tablepos,
+				 size_t *tablepos,
 				 const Stringprep_table_element * table,
-                                 size_t table_size)
+				 size_t table_size)
 {
   size_t j;
   ssize_t pos;
 
   for (j = 0; j < ucs4len; j++)
-    if ((pos = stringprep_find_character_in_table (ucs4[j], table, table_size)) != -1)
+    if ((pos =
+	 stringprep_find_character_in_table (ucs4[j], table,
+					     table_size)) != -1)
       {
 	if (tablepos)
 	  *tablepos = pos;
@@ -107,18 +110,19 @@ stringprep_find_string_in_table (uint32_t * ucs4,
 
 static int
 stringprep_apply_table_to_string (uint32_t * ucs4,
-				  size_t * ucs4len,
+				  size_t *ucs4len,
 				  size_t maxucs4len,
 				  const Stringprep_table_element * table,
-                                  size_t table_size)
+				  size_t table_size)
 {
   ssize_t pos;
   size_t i, maplen;
-  uint32_t *src = ucs4; /* points to unprocessed data */
-  size_t srclen = *ucs4len; /* length of unprocessed data */
+  uint32_t *src = ucs4;		/* points to unprocessed data */
+  size_t srclen = *ucs4len;	/* length of unprocessed data */
 
   while ((pos = stringprep_find_string_in_table (src, srclen,
-						 &i, table, table_size)) != -1)
+						 &i, table,
+						 table_size)) != -1)
     {
       for (maplen = STRINGPREP_MAX_MAP_CHARS;
 	   maplen > 0 && table[i].map[maplen - 1] == 0; maplen--)
@@ -175,7 +179,7 @@ stringprep_apply_table_to_string (uint32_t * ucs4,
  *   #Stringprep_rc error code.
  **/
 int
-stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
+stringprep_4i (uint32_t * ucs4, size_t *len, size_t maxucs4len,
 	       Stringprep_profile_flags flags,
 	       const Stringprep_profile * profile)
 {
@@ -220,7 +224,8 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 
 	case STRINGPREP_PROHIBIT_TABLE:
 	  k = stringprep_find_string_in_table (ucs4, ucs4len,
-					       NULL, profile[i].table, profile[i].table_size);
+					       NULL, profile[i].table,
+					       profile[i].table_size);
 	  if (k != -1)
 	    return STRINGPREP_CONTAINS_PROHIBITED;
 	  break;
@@ -231,7 +236,8 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 	  if (flags & STRINGPREP_NO_UNASSIGNED)
 	    {
 	      k = stringprep_find_string_in_table
-		(ucs4, ucs4len, NULL, profile[i].table, profile[i].table_size);
+		(ucs4, ucs4len, NULL, profile[i].table,
+		 profile[i].table_size);
 	      if (k != -1)
 		return STRINGPREP_CONTAINS_UNASSIGNED;
 	    }
@@ -241,7 +247,8 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 	  if (UNAPPLICAPLEFLAGS (flags, profile[i].flags))
 	    break;
 	  rc = stringprep_apply_table_to_string
-	    (ucs4, &ucs4len, maxucs4len, profile[i].table, profile[i].table_size);
+	    (ucs4, &ucs4len, maxucs4len, profile[i].table,
+	     profile[i].table_size);
 	  if (rc != STRINGPREP_OK)
 	    return rc;
 	  break;
@@ -265,7 +272,8 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 		  done_prohibited = 1;
 		  k = stringprep_find_string_in_table (ucs4, ucs4len,
 						       NULL,
-						       profile[j].table, profile[j].table_size);
+						       profile[j].table,
+						       profile[j].table_size);
 		  if (k != -1)
 		    return STRINGPREP_BIDI_CONTAINS_PROHIBITED;
 		}
@@ -273,14 +281,16 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 		{
 		  done_ral = 1;
 		  if (stringprep_find_string_in_table
-		      (ucs4, ucs4len, NULL, profile[j].table, profile[j].table_size) != -1)
+		      (ucs4, ucs4len, NULL, profile[j].table,
+		       profile[j].table_size) != -1)
 		    contains_ral = j;
 		}
 	      else if (profile[j].operation == STRINGPREP_BIDI_L_TABLE)
 		{
 		  done_l = 1;
 		  if (stringprep_find_string_in_table
-		      (ucs4, ucs4len, NULL, profile[j].table, profile[j].table_size) != -1)
+		      (ucs4, ucs4len, NULL, profile[j].table,
+		       profile[j].table_size) != -1)
 		    contains_l = j;
 		}
 
@@ -293,9 +303,15 @@ stringprep_4i (uint32_t * ucs4, size_t * len, size_t maxucs4len,
 	    if (contains_ral != SIZE_MAX)
 	      {
 		if (!(stringprep_find_character_in_table
-		      (ucs4[0], profile[contains_ral].table, profile[contains_ral].table_size) != -1 &&
-		      stringprep_find_character_in_table
-		      (ucs4[ucs4len - 1], profile[contains_ral].table, profile[contains_ral].table_size) != -1))
+		      (ucs4[0], profile[contains_ral].table,
+		       profile[contains_ral].table_size) != -1
+		      &&
+		      stringprep_find_character_in_table (ucs4[ucs4len - 1],
+							  profile
+							  [contains_ral].table,
+							  profile
+							  [contains_ral].table_size)
+		      != -1))
 		  return STRINGPREP_BIDI_LEADTRAIL_NOT_RAL;
 	      }
 	  }
@@ -625,7 +641,7 @@ stringprep_profile (const char *in,
  *   This usually indicate a problem in the calling application.
  * @STRINGPREP_UNKNOWN_PROFILE: The supplied profile name was not
  *   known to the library.
- * @STRINGPREP_ICONV_ERROR: Could not convert string in locale encoding.
+ * @STRINGPREP_ICONV_ERROR: Character encoding conversion error.
  * @STRINGPREP_NFKC_FAILED: The Unicode NFKC operation failed.  This
  *   usually indicate an internal error in the library.
  * @STRINGPREP_MALLOC_ERROR: The malloc() was out of memory.  This is
